@@ -8,7 +8,7 @@ Created on Mon Nov  1 11:02:08 2021
 import matplotlib.pyplot as plt
 import numpy as np 
 
-from fh_funcao_pertinencia import funcao_pertinencia
+from fh_fuzzy.fh_funcao_pertinencia import funcao_pertinencia
 
 class operacoes:
     
